@@ -1,4 +1,5 @@
 import os
+from collections import Counter
 
 import matplotlib.pyplot as plt
 import numpy as np
@@ -21,8 +22,24 @@ class Eda:
         numerical_vals: DataFrame
         categorical_vals: DataFrame
         """
-        numerical_vals = df.select_dtypes(exclude=["object", "bool"])
-        categorical_vals = df.select_dtypes(include=["object", "bool"])
+        numerical_vals = df[
+            [
+                col
+                for col in df.select_dtypes(
+                    exclude=["object", "bool", "datetime"]
+                ).columns
+                # ID columns values aren't particularly important to examine
+                if "_id" not in str(col)
+            ]
+        ]
+
+        categorical_vals = df[
+            [
+                col
+                for col in df.select_dtypes(include=["object", "bool"]).columns
+                if "_id" not in str(col)
+            ]
+        ]
 
         return numerical_vals, categorical_vals
 
@@ -53,6 +70,9 @@ class Eda:
         for col in categorical_vals.columns:
             if "_id" in col:
                 continue
+            # Booleans can be recoded as floats but still are good as booleans
+            elif categorical_vals[col].dtypes == bool:
+                continue
             try:
                 # Test two random values
                 float(categorical_vals[col][0])
@@ -104,7 +124,9 @@ class Eda:
                 lst.append(
                     {
                         col: "Considering excluding because {}% of column is null.".format(
-                            (df[col].isnull().sum() / float(df.shape[0]) * 100.0)
+                            round(
+                                (df[col].isnull().sum() / float(df.shape[0]) * 100.0), 2
+                            )
                         )
                     }
                 )
@@ -123,12 +145,12 @@ class Eda:
                     lst.append(
                         {
                             col: "Considering excluding because column variance is low ({})".format(
-                                df[col].var()
+                                round(df[col].var(), 2)
                             )
                         }
                     )
             elif df[col].dtype in ["object", "bool"]:
-                if len(df[col].unique()) > 200:
+                if len(df[col].unique()) > 500:
                     lst.append(
                         {
                             col: "Considering excluding because object column has large number of unique values ({})".format(
@@ -216,6 +238,9 @@ class Eda:
 
         numerical_vals, _ = self.separate_cols_by_type(df)
 
+        # Need to fill zeros to get accurate percentile numbers
+        numerical_vals.fillna(0, inplace=True)
+
         if numerical_vals.empty:
             return "No numerical columns to graph."
 
@@ -229,13 +254,14 @@ class Eda:
             ax.set_title(col)
 
             sns.violinplot(
-                x=df[col], ax=ax,
+                x=numerical_vals[col],
+                ax=ax,
             )
 
             text = "75th Percentile: {}\nMedian: {}\n25th Percentile: {}".format(
-                round(np.percentile(df[col], 75), 2),
-                round(np.median(df[col]), 2),
-                round(np.percentile(df[col], 25), 2),
+                round(np.percentile(numerical_vals[col], 75), 2),
+                round(np.median(numerical_vals[col]), 2),
+                round(np.percentile(numerical_vals[col], 25), 2),
             )
 
             # Place a text box in upper left in axes coords
@@ -272,20 +298,43 @@ class Eda:
         iter_bar = progressbar.ProgressBar()
         for col in iter_bar(categorical_vals):
             try:
-                if len(df[col].unique()) > 100 or len(df[col].unique()) == 1:
+                if len(df[col].unique()) == 1:
                     continue
 
+                # More values than this doesn't display well, just show the top values
+                if len(df[col].unique()) > 45:
+                    adjust_vals = df[
+                        df[col].isin([x[0] for x in Counter(df[col]).most_common(45)])
+                    ][col]
                 else:
-                    fig = plt.figure(figsize=(7, 7))
-                    ax = fig.add_subplot(111)
-                    ax.set_title(col)
+                    adjust_vals = df[col]
 
-                    counts_df = df[col].value_counts().reset_index()
-                    counts_df.sort_values(by=col, ascending=False, inplace=True)
+                fig = plt.figure(figsize=(7, 7))
+                ax = fig.add_subplot(111)
+                ax.set_title(col)
+
+                counts_df = adjust_vals.value_counts().reset_index()
+                counts_df.sort_values(by=col, ascending=False, inplace=True)
+
+                if adjust_vals.dtypes == bool:
+                    # For some reason seaborn flips these incorrectly for boolean variables
                     sns.barplot(
-                        x=counts_df[col], y=counts_df["index"], ax=ax,
+                        x=counts_df["index"],
+                        y=counts_df[col],
+                        ax=ax,
                     )
-                    plt.tight_layout()
-                    plt.savefig(f"{path}bargraph_{col}.png")
+
+                else:
+                    sns.barplot(
+                        x=counts_df[col],
+                        y=counts_df["index"],
+                        ax=ax,
+                    )
+
+                ax.set_xlabel("Count")
+                ax.set_ylabel("Values")
+
+                plt.tight_layout()
+                plt.savefig(f"{path}bargraph_{col}.png")
             except Exception:
                 continue
